pub struct ResponseTiming {
pub time_to_first_byte: Option<u64>,
pub time_to_last_byte: Option<u64>,
pub connect_time_ms: Option<u64>,
pub ssl_time_ms: Option<u64>,
}Fields
time_to_first_byte: Option<u64>time_to_last_byte: Option<u64>connect_time_ms: Option<u64>TCP connect time in milliseconds for the upstream connection (new connections only).
ssl_time_ms: Option<u64>TLS handshake time in milliseconds for the upstream connection (new connections only).